﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Threading;
using System.ComponentModel;
using System.Windows.Data;

namespace Silverlight3Clock {

    public partial class MainPage : UserControl {

        private Storyboard _storyBoard;

        private Clock _clock;

        public MainPage() {
            InitializeComponent();

            // use SizeChanged instead of Loaded, Application.Current.Host.Content.ActualWidth can
            // have invalid value in Loaded
            this.SizeChanged += MainPage_SizeChanged;
        }

        void MainPage_SizeChanged(object sender, RoutedEventArgs e) {
            // only do this once
            if (_clock == null) {

                _clock = new Clock();

                this.DataContext = _clock;

                // Calculate FontSize
                this.FontSize = Application.Current.Host.Content.ActualWidth / 8;

                // Create Storyboard
                _storyBoard = new Storyboard();
                _storyBoard.Duration = new Duration(new TimeSpan(0, 0, 16));
                _storyBoard.RepeatBehavior = RepeatBehavior.Forever;

                var c = new SubstringConverter();

                // Create TextBox Controls + Animations
                for (int i = 0; i < _clock.Time.Length; i++) {

                    // Create TextBox 
                    TextBlock tb = new TextBlock() {
                        HorizontalAlignment = HorizontalAlignment.Center,
                        VerticalAlignment = VerticalAlignment.Center,
                        Projection = new PlaneProjection() {
                            CenterOfRotationZ = Application.Current.Host.Content.ActualWidth / -2.1
                        }
                    };
                    gridContent.Children.Add(tb);

                    // DataBind
                    tb.SetBinding(TextBlock.TextProperty, new Binding("Time") {
                        Mode = BindingMode.OneWay,
                        ConverterParameter = i,
                        Converter = c
                    });

                    double y = 10 * -i + 220;
                    DoubleAnimation animation = new DoubleAnimation() {
                        From = y,
                        Duration = new Duration(new TimeSpan(0, 0, 8)),
                        To = y + 360,
                        RepeatBehavior = RepeatBehavior.Forever
                    };
                    Storyboard.SetTarget(animation, tb.Projection);
                    Storyboard.SetTargetProperty(animation, new PropertyPath("RotationY"));
                    _storyBoard.Children.Add(animation);

                    animation = new DoubleAnimation() {
                        From = 0,
                        Duration = _storyBoard.Duration,
                        To = 360,
                        RepeatBehavior = RepeatBehavior.Forever
                    };
                    Storyboard.SetTarget(animation, tb.Projection);
                    Storyboard.SetTargetProperty(animation, new PropertyPath("RotationZ"));
                    _storyBoard.Children.Add(animation);

                    // TODO change opacity
                    //r.SetBinding(TextBlock.OpacityProperty, new Binding("RotationY") {
                    //    Mode = BindingMode.OneWay,
                    //    Converter = new OpacityConverter(),
                    //    Source = r.Projection
                    //});
                }
                _storyBoard.Begin();
            }
        }

        
    }
}
